@@ -5,6 +5,10 @@ from marko.block import FencedCode
 from ...snippet import Snippet
 
 
+# NOTE:
+# Move all the `script/task` related code to corresponding plugins
+
+
 class HtmlRenderer(html_renderer.HTMLRenderer):
 
     # Render
@@ -14,6 +18,8 @@ class HtmlRenderer(html_renderer.HTMLRenderer):
         header = [element.lang] + element.extra.split()
         snippet = Snippet(input, header=header)
         snippet.process(self.document)
+
+        # Script
         if snippet.output is not None:
             if snippet.type == "script":
 
@@ -35,6 +41,23 @@ class HtmlRenderer(html_renderer.HTMLRenderer):
                 return output
 
             return snippet.output
+
+        # Task
+        if snippet.type == "task" and snippet.props.get("id"):
+
+            # Return output
+            task = snippet.props["id"]
+            target = copy(element)
+            target.lang = "bash"
+            target.extra = ""
+            target.children = [RawText(f"$ livemark run {task}")]
+            output = '<div class="livemark-task">'
+            output += super().render_fenced_code(target)
+            output += "\n"
+            output += super().render_fenced_code(element)
+            output += "</div>"
+            return output
+
         return super().render_fenced_code(element)
 
 
